@@ -13,12 +13,11 @@ sub _generate_delegation{
     # If it has a reader, we must use it to make method modifiers work
     my $reader = $attr->get_read_method() || $attr->get_read_method_ref();
 
-    my $can_be_optimized = $attr->{_method_delegation_can_be_optimized};
+    my $can_be_optimized = $attr->{_mouse_cache_method_delegation_can_be_optimized};
 
     if(!defined $can_be_optimized){
         my $tc = $attr->type_constraint;
-
-        $attr->{_method_delegation_can_be_optimized} =
+        $attr->{_mouse_cache_method_delegation_can_be_optimized} =
             (defined($tc) && $tc->is_a_type_of('Object'))
             && ($attr->is_required || $attr->has_default || $attr->has_builder)
             && ($attr->is_lazy || !$attr->has_clearer);
@@ -62,7 +61,7 @@ Mouse::Meta::Method::Delegation - A Mouse method generator for delegation method
 
 =head1 VERSION
 
-This document describes Mouse version 0.75
+This document describes Mouse version 0.76
 
 =head1 SEE ALSO
 
